|travis| |pypi| |zenodo|


.. |travis| image:: https://travis-ci.org/cltk/cltk.svg?branch=master
   :target: https://travis-ci.org/cltk/cltk

.. |rtd| image:: https://img.shields.io/readthedocs/cltk
   :target: http://docs.cltk.org/

.. |codecov| image:: https://codecov.io/gh/cltk/cltk/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/cltk/cltk

.. |pypi| image:: https://img.shields.io/pypi/v/cltk
   :target: https://pypi.org/project/cltk/

.. |zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3445585.svg
   :target: https://doi.org/10.5281/zenodo.3445585

.. |binder| image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/cltk/tutorials/master


The Classical Language Toolkit (CLTK) is a Python library offering natural language processing (NLP) for pre-modern languages.


Installation
============

For the CLTK's latest version:

.. code-block:: bash

   $ pip install cltk

For more information, see `Installation docs <https://docs.cltk.org/en/latest/installation.html>`_ or, to install from source, `Development <https://docs.cltk.org/en/latest/development.html>`_.

Pre-1.0 software remains available on the `branch v0.1.x <https://github.com/cltk/cltk/tree/v0.1.x>`_ and docs at `<https://legacy.cltk.org>`_.


Documentation
=============

Documentation at `<https://docs.cltk.org>`_.


Citation
========

.. code-block:: bibtex

   @Misc{johnsonetal2014,
    author = {Johnson, Kyle P. and Patrick Burns and John Stewart and Todd Cook and Clément Besnier and William J. B. Mattingly},
    title = {CLTK: The Classical Language Toolkit},
    url = {https://github.com/cltk/cltk},
    year = {2014--2021},
   }


License
=======

.. |year| date:: %Y

Copyright (c) 2014-|year| Kyle P. Johnson under the `MIT License <https://github.com/cltk/cltk/blob/master/LICENSE>`_.
